@@ -10,6 +10,7 @@ import re
 import random
 import base64
 import html as html_decode
+from colorama import Fore
 
 import xlrd
 import xlwt
@@ -30,9 +31,22 @@ for div in response.html.xpath('.//div'):
 """
 
 
-def test(data):
+def test():
     print('hello world!')
-    print(data)
+    print(Fore.YELLOW + '人生苦短，我用Python！')
+    print(Fore.LIGHTWHITE_EX + '人生苦短，我用Python！')
+    print(Fore.LIGHTRED_EX + '人生苦短，我用Python！')
+    print(Fore.LIGHTMAGENTA_EX + '人生苦短，我用Python！')
+    print(Fore.LIGHTGREEN_EX + '人生苦短，我用Python！')
+    print(Fore.LIGHTCYAN_EX + '人生苦短，我用Python！')
+    print(Fore.LIGHTBLUE_EX + '人生苦短，我用Python！')
+    print(Fore.CYAN + '人生苦短，我用Python！')
+    print(Fore.LIGHTYELLOW_EX + '人生苦短，我用Python！')
+    print(Fore.RED + '人生苦短，我用Python！')
+    print(Fore.BLUE + '人生苦短，我用Python！')
+    print(Fore.GREEN + '人生苦短，我用Python！')
+    print(Fore.MAGENTA + '人生苦短，我用Python！')
+    print(Fore.RESET + '人生苦短，我用Python！')
 
 
 def md5value(data):
@@ -462,6 +476,7 @@ XPATH: Node XPATH Syntax
 retur: Node, the front page display text data
 """
 
+
 def html_nodes_text(XPATH_list):
     """
     :param XPATH_list: Type == list 传入Xpath匹配到的节点群
@@ -472,3 +487,27 @@ def html_nodes_text(XPATH_list):
         result = html_decode.unescape(html_clean(str(etree.tostring(Xpath)))).lstrip("b'").rstrip("'")
         text_list.append(result)
     return text_list
+
+
+def console(data):
+    """
+    Need to change colors to unwrap annotations for testing
+    需要更换颜色自行解开注释进行测试
+    :param data: Type == any
+    :return: data
+    """
+    #     print(Fore.YELLOW + '人生苦短，我用Python！')
+    #     print(Fore.LIGHTWHITE_EX + '人生苦短，我用Python！')
+    #     print(Fore.LIGHTRED_EX + '人生苦短，我用Python！')
+    #     print(Fore.LIGHTMAGENTA_EX + '人生苦短，我用Python！')
+    #     print(Fore.LIGHTGREEN_EX + '人生苦短，我用Python！')
+    #     print(Fore.LIGHTCYAN_EX + '人生苦短，我用Python！')
+    #     print(Fore.LIGHTBLUE_EX + '人生苦短，我用Python！')
+    #     print(Fore.CYAN + '人生苦短，我用Python！')
+    #     print(Fore.LIGHTYELLOW_EX + '人生苦短，我用Python！')
+    #     print(Fore.RED + '人生苦短，我用Python！')
+    #     print(Fore.BLUE + '人生苦短，我用Python！')
+    #     print(Fore.GREEN + '人生苦短，我用Python！')
+    #     print(Fore.MAGENTA + '人生苦短，我用Python！')
+    #     print(Fore.RESET + '人生苦短，我用Python！')
+    print(Fore.LIGHTYELLOW_EX + f'{data}')
